@@ -917,7 +917,6 @@ def generate_fm_2additive_convex_withsomeindependent(num, n):
 def prepare_fm_sparse( n, tupsize):
     try:
         trace( "void py_prepare_fm_sparse(int n, int tupsize, int* tuples, struct fm_env_sparse* out_env)")
-        # if tupsize == 0: tupsize = 1
         ptuplesnp, ptuples = create_intc_zeros_as_CFFI_int( tupsize)
         pout_env_sparse = ffi.new( "struct fm_env_sparse *")
         fm.py_prepare_fm_sparse( n, tupsize, ptuples, pout_env_sparse)
@@ -996,94 +995,98 @@ def max_subset_sparse(x, n, S, cardS, env):
 
 # Generated python wrapper for:
 #    double py_ChoquetMob_sparse(double* x, int n, struct fm_env_sparse* env)
-def ChoquetMob_sparse(x, n, env):
+def ChoquetMob_sparse(x, env):
     trace( "double py_ChoquetMob_sparse(double* x, int n, struct fm_env_sparse* env)")
+    n = len( x)
     pxnp, px = convert_py_float_to_cffi( x)
     yy = fm.py_ChoquetMob_sparse( px, n, env)
     return yy
 
 
 # Generated python wrapper for:
-#    void py_ShapleyMob_sparse(double* v, int n, struct fm_env_sparse* out_env)
-def ShapleyMob_sparse(v, n, out_env):
-    trace( "void py_ShapleyMob_sparse(double* v, int n, struct fm_env_sparse* out_env)")
-    pvnp, pv = convert_py_float_to_cffi( v)
-    fm.py_ShapleyMob_sparse( pv, n, out_env)
-    return out_env
+#    void py_add_tuple_sparse(int tupsize, int* tuple, double v, struct fm_env_sparse* env)
+def add_tuple_sparse(tuple, v, env):
+    trace( "void py_add_tuple_sparse(int tupsize, int* tuple, double v, struct fm_env_sparse* env)")
+    # ptuplenp, ptuple = convert_py_int_to_cffi( tuple)
+    tupsize = len( tuple)
+    ptuplenp, ptuple = convert_py_int_to_cffi( tuple)
+    fm.py_add_tuple_sparse( tupsize, ptuple, v, env)
 
 
 # Generated python wrapper for:
-#    void py_BanzhafMob_sparse(double* v, int n, struct fm_env_sparse* out_env)
-def BanzhafMob_sparse(v, n, out_env):
-    trace( "void py_BanzhafMob_sparse(double* v, int n, struct fm_env_sparse* out_env)")
-    pvnp, pv = convert_py_float_to_cffi( v)
-    fm.py_BanzhafMob_sparse( pv, n, out_env)
-    return out_env
+#    void py_ShapleyMob_sparse(double* out_v, int n, struct fm_env_sparse* env)
+def ShapleyMob_sparse(n, env):
+    trace( "void py_ShapleyMob_sparse(double* out_v, int n, struct fm_env_sparse* env)")
+    pout_vnp, pout_v = create_float_zeros_as_CFFI_double( n)
+    fm.py_ShapleyMob_sparse( pout_v, n, env)
+    return pout_vnp
 
 
 # Generated python wrapper for:
-#    void py_populate_fm_2add_sparse(double* singletons, int numpairs, double* pairs, int* indicesp1, int* indicesp2, struct fm_env_sparse* out_env)
-def populate_fm_2add_sparse(singletons, numpairs, pairs, indicesp1, indicesp2, out_env):
-    trace( "void py_populate_fm_2add_sparse(double* singletons, int numpairs, double* pairs, int* indicesp1, int* indicesp2, struct fm_env_sparse* out_env)")
+#    void py_BanzhafMob_sparse(double* out_v, int n, struct fm_env_sparse* env)
+def BanzhafMob_sparse(n, env):
+    trace( "void py_BanzhafMob_sparse(double* out_v, int n, struct fm_env_sparse* env)")
+    pout_vnp, pout_v = create_float_zeros_as_CFFI_double( n)
+    fm.py_BanzhafMob_sparse( pout_v, n, env)
+    return pout_vnp
+
+
+
+# Generated python wrapper for:
+#    void py_populate_fm_2add_sparse(double* singletons, int numpairs, double* pairs, int* indicesp1, int* indicesp2, struct fm_env_sparse* env)
+def populate_fm_2add_sparse(singletons, numpairs, pairs, indicesp1, indicesp2, env):
+    trace( "void py_populate_fm_2add_sparse(double* singletons, int numpairs, double* pairs, int* indicesp1, int* indicesp2, struct fm_env_sparse* env)")
     psingletonsnp, psingletons = convert_py_float_to_cffi( singletons)
     ppairsnp, ppairs = convert_py_float_to_cffi( pairs)
     pindicesp1np, pindicesp1 = convert_py_int_to_cffi( indicesp1)
     pindicesp2np, pindicesp2 = convert_py_int_to_cffi( indicesp2)
-    fm.py_populate_fm_2add_sparse( psingletons, numpairs, ppairs, pindicesp1, pindicesp2, out_env)
-    return out_env
+    fm.py_populate_fm_2add_sparse( psingletons, numpairs, ppairs, pindicesp1, pindicesp2, env)
+    return env
 
 
 # Generated python wrapper for:
-#    void py_add_pair_sparse(int i, int j, double v, struct fm_env_sparse* out_env)
-def add_pair_sparse(i, j, v, out_env):
-    trace( "void py_add_pair_sparse(int i, int j, double v, struct fm_env_sparse* out_env)")
-    fm.py_add_pair_sparse( i, j, v, out_env)
-    return out_env
+#    void py_add_pair_sparse(int i, int j, double v, struct fm_env_sparse* env)
+def add_pair_sparse(i, j, v, env):
+    trace( "void py_add_pair_sparse(int i, int j, double v, struct fm_env_sparse* env)")
+    fm.py_add_pair_sparse( i, j, v, env)
+    return env
 
 
 # Generated python wrapper for:
-#    void py_add_tuple_sparse(int tupsize, int* tuple, double v, struct fm_env_sparse* out_env)
-def add_tuple_sparse(tupsize, tuple, v, out_env):
-    trace( "void py_add_tuple_sparse(int tupsize, int* tuple, double v, struct fm_env_sparse* out_env)")
-    ptuplenp, ptuple = convert_py_int_to_cffi( tuple)
-    fm.py_add_tuple_sparse( tupsize, ptuple, v, out_env)
-    return out_env
-
-
-# Generated python wrapper for:
-#    void py_populate_fm_2add_sparse_from2add(int n, double* v, struct fm_env_sparse* out_env)
-def populate_fm_2add_sparse_from2add(n, v, out_env):
-    trace( "void py_populate_fm_2add_sparse_from2add(int n, double* v, struct fm_env_sparse* out_env)")
+#    void py_populate_fm_2add_sparse_from2add(int n, double* v, struct fm_env_sparse* env)
+def populate_fm_2add_sparse_from2add(n, v, env):
+    trace( "void py_populate_fm_2add_sparse_from2add(int n, double* v, struct fm_env_sparse* env)")
     pvnp, pv = convert_py_float_to_cffi( v)
-    fm.py_populate_fm_2add_sparse_from2add( n, pv, out_env)
-    return out_env
+    fm.py_populate_fm_2add_sparse_from2add( n, pv, env)
+    return env
 
 
 # Generated python wrapper for:
-#    void py_expand_2add_full(double* v, struct fm_env_sparse* out_env)
-def expand_2add_full(v, out_env):
-    trace( "void py_expand_2add_full(double* v, struct fm_env_sparse* out_env)")
+#    env)void py_expand_2add_full(double* v, struct fm_env_sparse* env)
+def expand_2add_full(v, env):
+    trace( "env)void py_expand_2add_full(double* v, struct fm_env_sparse* env)")
     pvnp, pv = convert_py_float_to_cffi( v)
-    fm.py_expand_2add_full( pv, out_env)
-    return out_env
+    fm.py_expand_2add_full( pv, env)
+    return env
 
 
 # Generated python wrapper for:
-#    void py_expand_sparse_full(double* v, struct fm_env_sparse* out_env)
-def expand_sparse_full(v, out_env):
-    trace( "void py_expand_sparse_full(double* v, struct fm_env_sparse* out_env)")
+#    void py_expand_sparse_full(double* v, struct fm_env_sparse* env)
+def expand_sparse_full(v, env):
+    trace( "void py_expand_sparse_full(double* v, struct fm_env_sparse* env)")
     pvnp, pv = convert_py_float_to_cffi( v)
-    fm.py_expand_sparse_full( pv, out_env)
-    return out_env
+    fm.py_expand_sparse_full( pv, env)
+    return env
 
 
 # Generated python wrapper for:
-#    void py_sparse_get_singletons(int n, double* v, struct fm_env_sparse* out_env)
-def sparse_get_singletons(n, v, out_env):
-    trace( "void py_sparse_get_singletons(int n, double* v, struct fm_env_sparse* out_env)")
+#    void py_sparse_get_singletons(int n, double* v, struct fm_env_sparse* env)
+def sparse_get_singletons(n, v, env):
+    trace( "void py_sparse_get_singletons(int n, double* v, struct fm_env_sparse* env)")
     pvnp, pv = convert_py_float_to_cffi( v)
-    fm.py_sparse_get_singletons( n, pv, out_env)
-    return out_env
+    fm.py_sparse_get_singletons( n, pv, env)
+    return env
+
 
 
 # Generated python wrapper for:
@@ -1123,11 +1126,9 @@ def generate_fm_kadditive_convex_sparse(n, k, nonzero, env):
 
 
 # Generated python wrapper for:
-#    void py_Nonmodularityindex_sparse(double* w, int n, struct fm_env_sparse* out_env)
-def Nonmodularityindex_sparse(w, n, out_env):
-    trace( "void py_Nonmodularityindex_sparse(double* w, int n, struct fm_env_sparse* out_env)")
-    pwnp, pw = convert_py_float_to_cffi( w)
-    fm.py_Nonmodularityindex_sparse( pw, n, out_env)
-    return out_env
-
-
+#    void py_Nonmodularityindex_sparse(double* out_w, int n, struct fm_env_sparse* env)
+def Nonmodularityindex_sparse(n, env):
+    trace( "void py_Nonmodularityindex_sparse(double* out_w, int n, struct fm_env_sparse* env)")
+    pout_wnp, pout_w = create_float_zeros_as_CFFI_double( 2 ** n)
+    fm.py_Nonmodularityindex_sparse( pout_w, n, env)
+    return pout_wnp
