@@ -110,16 +110,32 @@ pout_Mob = ffi.cast("double *", out_Mob.ctypes.data);
 print( "v: ", v)
 print( "w: ", w)
 
+fm.py_fm_free( env);
+
+
 n = 3
-tupsize = 1
+tupsize = 0
 tuples=np.zeros( tupsize, np.intc)
 ptuples = ffi.cast("int *", tuples.ctypes.data)
 env_sparse = ffi.new( "struct fm_env_sparse *")
+print( "--- py_prepare_fm_sparse")
 fm.py_prepare_fm_sparse( n, tupsize, ptuples, env_sparse)
 
+print( "--- py_tuple_cardinality_sparse")
+i = 0;
+tup_card = fm.py_tuple_cardinality_sparse(i, env_sparse)
+print( "i: ", i)
+print( "tup_card: ", tup_card)
+
+print( "--- py_get_num_tuples")
+num_tup = fm.py_get_num_tuples( env_sparse)
+print( "num_tup: ", num_tup)
+
+
+
+print( "--- py_free_fm_sparse")
+fm.py_free_fm_sparse( env_sparse)
 
 
 
 
-
-fm.py_fm_free( env);
