@@ -765,123 +765,134 @@ tupsize = 0
 env_sparse = pyw.prepare_fm_sparse( n, tupsize)
 
 # Test wrapper for:
-#    void py_free_fm_sparse( struct fm_env_sparse* env)
-pyw.free_fm_sparse( env_sparse)
+#    void py_add_tuple_sparse(int tupsize, int* tuple, double v, struct fm_env_sparse* env)
+v = 0.2
+tuple = [1, 3, 4]
+pyw.add_tuple_sparse( tuple, v, env_sparse)
+print( "tuple: ", tuple)
 
-sys.exit()
+# Test wrapper for:
+#    void py_ShapleyMob_sparse(double* out_v, int n, struct fm_env_sparse* env)
+n = 3
+v = pyw.ShapleyMob_sparse(n, env_sparse)
+print( "n: ", n)
+print( "Shapley values: ", v)
+
+# Test wrapper for:
+#    void py_BanzhafMob_sparse(double* out_v, int n, struct fm_env_sparse* env)
+n = 3
+v = pyw.BanzhafMob_sparse(n, env_sparse)
+print( "n: ", n)
+print( "Banzhaf values: ", v)
+
+# Test wrapper for:
+#    void py_add_pair_sparse(int i, int j, double v, struct fm_env_sparse* env)
+v = 0.2
+i = 2
+j = 5
+pyw.add_pair_sparse(i, j, v, env_sparse)
+print( "v: ", v)
+print( "i: ", i)
+print( "j: ", j)
 
 
 # Test wrapper for:
-#    int py_tuple_cardinality_sparse(int i, struct fm_env_sparse* env)
-# pyw.tuple_cardinality_sparse(i, env)
-# not documented in R or Python user guide
-
-# Test wrapper for:
-#    int py_get_num_tuples(struct fm_env_sparse* env)
-# pyw.get_num_tuples(env)
-# not documented in R or Python user guide
-
-# Test wrapper for:
-#    int py_get_sizearray_tuples(struct fm_env_sparse* env)
-# pyw.get_sizearray_tuples(env)
-# not documented in R or Python user guide
-
-# Test wrapper for:
-#    int py_is_inset_sparse(int A, int card, int i, struct fm_env_sparse* env)
-# pyw.is_inset_sparse(A, card, i, env)
-# not documented in R or Python user guide
-
-# Test wrapper for:
-#    int py_is_subset_sparse(int A, int cardA, int B, int cardB, struct fm_env_sparse* env)
-# pyw.is_subset_sparse(A, cardA, B, cardB, env)
-# not documented in R or Python user guide
-
-# Test wrapper for:
-#    double py_min_subset_sparse(double* x, int n, int S, int cardS, struct fm_env_sparse* env)
-# pyw.min_subset_sparse(x, n, S, cardS, env)
-# not documented in R or Python user guide
-
-# Test wrapper for:
-#    double py_max_subset_sparse(double* x, int n, int S, int cardS, struct fm_env_sparse* env)
-# pyw.max_subset_sparse(x, n, S, cardS, env)
-# not documented in R or Python user guide
-
-# Test wrapper for:
-#    double py_ChoquetMob_sparse(double* x, int n, struct fm_env_sparse* env)
-# pyw.ChoquetMob_sparse(x, n, env)
-# not documented in R or Python user guide
-
-sys.exit()
+#    void py_populate_fm_2add_sparse_from2add(int n, double* v, struct fm_env_sparse* env)
+# n = 3
+# v = pyw.populate_fm_2add_sparse_from2add(n, v, env)
 
 
 # Test wrapper for:
-#    void py_ShapleyMob_sparse(double* v, int n, struct fm_env_sparse* out_env)
-# pyw.ShapleyMob_sparse(v, n, out_env)
-# not documented in R or Python user guide
+#    void py_populate_fm_2add_sparse(double* singletons, int numpairs, double* pairs, int* indicesp1, int* indicesp2, struct fm_env_sparse* env)
+# pyw.populate_fm_2add_sparse(singletons, numpairs, pairs, indicesp1, indicesp2, env)
+
+
 
 # Test wrapper for:
-#    void py_BanzhafMob_sparse(double* v, int n, struct fm_env_sparse* out_env)
-# pyw.BanzhafMob_sparse(v, n, out_env)
-# not documented in R or Python user guide
+#    env)void py_expand_2add_full(double* v, struct fm_env_sparse* env)
+# pyw.expand_2add_full(v, env)
 
-# Test wrapper for:
-#    void py_populate_fm_2add_sparse(double* singletons, int numpairs, double* pairs, int* indicesp1, int* indicesp2, struct fm_env_sparse* out_env)
-# pyw.populate_fm_2add_sparse(singletons, numpairs, pairs, indicesp1, indicesp2, out_env)
-# not documented in R or Python user guide
-
-# Test wrapper for:
-#    void py_add_pair_sparse(int i, int j, double v, struct fm_env_sparse* out_env)
-# pyw.add_pair_sparse(i, j, v, out_env)
-# not documented in R or Python user guide
-
-# Test wrapper for:
-#    void py_add_tuple_sparse(int tupsize, int* tuple, double v, struct fm_env_sparse* out_env)
-# pyw.add_tuple_sparse(tupsize, tuple, v, out_env)
-# not documented in R or Python user guide
-
-# Test wrapper for:
-#    void py_populate_fm_2add_sparse_from2add(int n, double* v, struct fm_env_sparse* out_env)
-# pyw.populate_fm_2add_sparse_from2add(n, v, out_env)
-# not documented in R or Python user guide
-
-# Test wrapper for:
-#    void py_expand_2add_full(double* v, struct fm_env_sparse* out_env)
-# pyw.expand_2add_full(v, out_env)
-# not documented in R or Python user guide
-
-# Test wrapper for:
-#    void py_expand_sparse_full(double* v, struct fm_env_sparse* out_env)
-# pyw.expand_sparse_full(v, out_env)
-# not documented in R or Python user guide
-
-# Test wrapper for:
-#    void py_sparse_get_singletons(int n, double* v, struct fm_env_sparse* out_env)
-# pyw.sparse_get_singletons(n, v, out_env)
-# not documented in R or Python user guide
 
 # Test wrapper for:
 #    int py_sparse_get_pairs(int* pairs, double* v, struct fm_env_sparse* env)
 # pyw.sparse_get_pairs(pairs, v, env)
-# not documented in R or Python user guide
 
 # Test wrapper for:
 #    int py_sparse_get_tuples(int* tuples, double* v, struct fm_env_sparse* env)
 # pyw.sparse_get_tuples(tuples, v, env)
-# not documented in R or Python user guide
 
 # Test wrapper for:
 #    int   py_generate_fm_2additive_convex_sparse(int n, struct fm_env_sparse* env)
 # pyw.generate_fm_2additive_convex_sparse(n, env)
-# not documented in R or Python user guide
 
 # Test wrapper for:
 #    int   py_generate_fm_kadditive_convex_sparse(int n, int k, int nonzero, struct fm_env_sparse* env)
 # pyw.generate_fm_kadditive_convex_sparse(n, k, nonzero, env)
-# not documented in R or Python user guide
 
 # Test wrapper for:
-#    void py_Nonmodularityindex_sparse(double* w, int n, struct fm_env_sparse* out_env)
-# pyw.Nonmodularityindex_sparse(w, n, out_env)
-# not documented in R or Python user guide
+#    void py_Nonmodularityindex_sparse(double* out_w, int n, struct fm_env_sparse* env)
+n =3
+w = pyw.Nonmodularityindex_sparse(n, env_sparse)
+print( "n: ", n)
+print( "w: ", w)
+
+# Test wrapper for:
+#    int py_tuple_cardinality_sparse(int i, struct fm_env_sparse* env)
+i = 0;
+tup_card = pyw.tuple_cardinality_sparse(i, env_sparse)
+print( "i: ", i)
+print( "tup_card: ", tup_card)
+
+# Test wrapper for:
+#    int py_get_num_tuples(struct fm_env_sparse* env)
+num_tup = pyw.get_num_tuples(env_sparse)
+print( "num_tup: ", num_tup)
+
+# Test wrapper for:
+#    int py_get_sizearray_tuples(struct fm_env_sparse* env)
+length = pyw.get_sizearray_tuples(env_sparse)
+print( "length of array of tuples: ", length)
+
+# Test wrapper for:
+#    int py_is_inset_sparse(int A, int card, int i, struct fm_env_sparse* env)
+A = 0
+card = 3
+i = 1
+is_contained = pyw.is_inset_sparse(A, card, i, env_sparse)
+print( "A: ", A)
+print( "card: ", card)
+print( "i: ", i)
+print( "is_contained: ", is_contained)
+
+# Test wrapper for:
+#    int py_is_subset_sparse(int A, int cardA, int B, int cardB, struct fm_env_sparse* env)
+A = 0
+cardA = 3
+B = 1
+cardB = 3
+is_subset = pyw.is_subset_sparse(A, cardA, B, cardB, env_sparse)
+print( "A: ", A)
+print( "cardA: ", cardA)
+print( "B: ", B)
+print( "cardB: ", cardB)
+print( "is_subset: ", is_subset)
+
+# Test wrapper for:
+#    double py_min_subset_sparse(double* x, int n, int S, int cardS, struct fm_env_sparse* env)
+# pyw.min_subset_sparse(x, n, S, cardS, env_sparse)
+
+# Test wrapper for:
+#    double py_max_subset_sparse(double* x, int n, int S, int cardS, struct fm_env_sparse* env)
+# pyw.max_subset_sparse(x, n, S, cardS, env_sparse)
 
 
+# Test wrapper for:
+#    double py_ChoquetMob_sparse(double* x, int n, struct fm_env_sparse* env)
+x = [0.1,0.05,0.2]
+c_i = pyw.ChoquetMob_sparse(x, env_sparse)
+print( "x: ", x)
+print( "Choquet integral: ", c_i)
+
+# Test wrapper for:
+#    void py_free_fm_sparse( struct fm_env_sparse* env)
+pyw.free_fm_sparse( env_sparse)
